@@ -222,6 +222,12 @@ class Resource:
         TERMINATING: str = "Terminating"
         ERROR: str = "Error"
         COMPLETE: str = "Complete"
+        DEPLOYING: str = "Deploying"
+        SCHEDULING_DISABLED = "Ready,SchedulingDisabled"
+        CRASH_LOOPBACK_OFF = "CrashLoopBackOff"
+        IMAGE_PULL_BACK_OFF = "ImagePullBackOff"
+        ERR_IMAGE_PULL = "ErrImagePull"
+        ACTIVE = "Active"
 
     class Condition:
         UPGRADEABLE: str = "Upgradeable"
@@ -251,6 +257,11 @@ class Resource:
         class Type:
             NETWORK_READY: str = "NetworkReady"
 
+    class Type:
+        CLUSTER_IP = "ClusterIP"
+        NODE_PORT = "NodePort"
+        LOAD_BALANCER = "LoadBalancer"
+
     class Interface:
         class State:
             UP: str = "up"
@@ -332,6 +343,7 @@ class Resource:
         SECURITY_ISTIO_IO: str = "security.istio.io"
         SECURITY_OPENSHIFT_IO: str = "security.openshift.io"
         SELF_NODE_REMEDIATION_MEDIK8S_IO: str = "self-node-remediation.medik8s.io"
+        SERVING_KNATIVE_DEV: str = "serving.knative.dev"
         SERVING_KSERVE_IO: str = "serving.kserve.io"
         SNAPSHOT_KUBEVIRT_IO: str = "snapshot.kubevirt.io"
         SNAPSHOT_STORAGE_K8S_IO: str = "snapshot.storage.k8s.io"
@@ -380,6 +392,7 @@ class Resource:
         hash_log_data: bool = True,
         ensure_exists: bool = False,
         kind_dict: Dict[Any, Any] | None = None,
+        wait_for_resource: bool = False,
     ):
         """
         Create an API resource
@@ -407,6 +420,7 @@ class Resource:
                 (example: Secret resource)
             ensure_exists (bool): Whether to check if the resource exists before when initializing the resource, raise if not.
             kind_dict (dict): dict which represents the resource object
+            wait_for_resource (bool): Waits for the resource to be created
         """
         if yaml_file and kind_dict:
             raise ValueError("yaml_file and resource_dict are mutually exclusive")
@@ -448,6 +462,7 @@ class Resource:
         self.yaml_file_contents: str = ""
         self.initial_resource_version: str = ""
         self.logger = self._set_logger()
+        self.wait_for_resource = wait_for_resource
 
         if ensure_exists:
             self._ensure_exists()
@@ -524,7 +539,7 @@ class Resource:
 
     def __enter__(self) -> "Resource":
         signal(SIGINT, self._sigint_handler)
-        return self.deploy()
+        return self.deploy(wait=self.wait_for_resource)
 
     def __exit__(
         self,
